@@ -428,7 +428,7 @@ sjp.frq <- function(varCount,
   # for continiuos x-axis-scale
   df$y <- as.numeric(as.character(df$y))
   # if categories start with zero, fix this here
-  if (min(df$y)==0) {
+  if (min(df$y)==0 && startAxisAt>0) {
     df$y <- df$y+1
   }
   # get the highest answer category of "y", so we know where the
